==> alg-alg-2.17.0-20200630.030208-4-sources.jar: cn/com/duiba/nezha/alg/alg/vo/dpa/PackageInfoDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.dpa;

/**
 * @author lijingzhe
 * @description 组件召回候选对象
 * @date 2020/6/17
 */
public class PackageInfoDo {
    /**
     * 广告位id
     */
    private Long slotId;
    /**
     * 组件ID包
     */
    private PackageIdDo packageIdDo = new PackageIdDo();
    /**
     * 活动访问pv
     */
    private Double reuqest;
    /**
     * 券点击pv
     */
    private Double click;
    /**
     * 消耗,分
     */
    private Double cost;
    /**
     * 转化
     */
    private Double effect;
    /**
     * 全局活动访问pv
     */
    private Double globalReuqest;
    /**
     * 全局券点击pv
     */
    private Double globalClick;
    /**
     * 全局消耗,分
     */
    private Double globalCost;
    /**
     * 全局转化pv
     */
    private Double globalEffect;

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public PackageIdDo getPackageIdDo() {
        return packageIdDo;
    }

    public void setPackageIdDo(PackageIdDo packageIdDo) {
        this.packageIdDo = packageIdDo;
    }

    public Double getReuqest() {
        return reuqest;
    }

    public void setReuqest(Double reuqest) {
        this.reuqest = reuqest;
    }

    public Double getClick() {
        return click;
    }

    public void setClick(Double click) {
        this.click = click;
    }

    public Double getCost() {
        return cost;
    }

    public void setCost(Double cost) {
        this.cost = cost;
    }

    public Double getEffect() {
        return effect;
    }

    public void setEffect(Double effect) {
        this.effect = effect;
    }

    public Double getGlobalReuqest() {
        return globalReuqest;
    }

    public void setGlobalReuqest(Double globalReuqest) {
        this.globalReuqest = globalReuqest;
    }

    public Double getGlobalClick() {
        return globalClick;
    }

    public void setGlobalClick(Double globalClick) {
        this.globalClick = globalClick;
    }

    public Double getGlobalCost() {
        return globalCost;
    }

    public void setGlobalCost(Double globalCost) {
        this.globalCost = globalCost;
    }

    public Double getGlobalEffect() {
        return globalEffect;
    }

    public void setGlobalEffect(Double globalEffect) {
        this.globalEffect = globalEffect;
    }
}

==> alg-alg-5.0.4-sources.jar: cn/com/duiba/nezha/alg/alg/vo/dpa/PackageInfoDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.dpa;

/**
 * @author lijingzhe
 * @description 组件召回候选对象
 * @date 2020/6/17
 */
public class PackageInfoDo {
    /**
     * 广告位id
     */
    private Long slotId;
    /**
     * 组件ID包
     */
    private PackageIdDo packageIdDo = new PackageIdDo();
    /**
     * 活动访问pv
     */
    private Double request;
    /**
     * 券点击pv
     */
    private Double click;
    /**
     * 消耗,分
     */
    private Double cost;
    /**
     * 转化
     */
    private Double effect;
    /**
     * 全局活动访问pv
     */
    private Double globalRequest;
    /**
     * 全局券点击pv
     */
    private Double globalClick;
    /**
     * 全局消耗,分
     */
    private Double globalCost;
    /**
     * 全局转化pv
     */
    private Double globalEffect;

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public PackageIdDo getPackageIdDo() {
        return packageIdDo;
    }

    public void setPackageIdDo(PackageIdDo packageIdDo) {
        this.packageIdDo = packageIdDo;
    }

    public Double getRequest() {
        return request;
    }

    public void setRequest(Double request) {
        this.request = request;
    }

    public Double getClick() {
        return click;
    }

    public void setClick(Double click) {
        this.click = click;
    }

    public Double getCost() {
        return cost;
    }

    public void setCost(Double cost) {
        this.cost = cost;
    }

    public Double getEffect() {
        return effect;
    }

    public void setEffect(Double effect) {
        this.effect = effect;
    }

    public Double getGlobalRequest() {
        return globalRequest;
    }

    public void setGlobalRequest(Double globalRequest) {
        this.globalRequest = globalRequest;
    }

    public Double getGlobalClick() {
        return globalClick;
    }

    public void setGlobalClick(Double globalClick) {
        this.globalClick = globalClick;
    }

    public Double getGlobalCost() {
        return globalCost;
    }

    public void setGlobalCost(Double globalCost) {
        this.globalCost = globalCost;
    }

    public Double getGlobalEffect() {
        return globalEffect;
    }

    public void setGlobalEffect(Double globalEffect) {
        this.globalEffect = globalEffect;
    }
}
